==> mongodbcom-integration-broker-0.1.7.tgz: package/bundle.js <==
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global = global || self, global.initIntegrationBroker = factory());
}(this, function () { 'use strict';

  function load ({ adv_id, pix_id }) {
    window.adroll_adv_id = adv_id;
    window.adroll_pix_id = pix_id
    ;(function (w, d, e, o, a) { w.__adroll_loaded = true; w.adroll = w.adroll || []; w.adroll.f = ['identify', 'track']; for (a = 0; a < w.adroll.f.length; a++) { w.adroll[w.adroll.f[a]] = w.adroll[w.adroll.f[a]] || (function (n) { return function () { w.adroll.push([n, arguments]); } })(w.adroll.f[a]); }e = d.createElement('script'); o = d.getElementsByTagName('script')[0]; e.async = 1; e.src = 'https://s.adroll.com/j/roundtrip.js'; o.parentNode.insertBefore(e, o); })(window, document);
  }

  const adroll = { load };

  function querystring (str) {
    const arr = (str || window.location.search).slice(1).split('&');
    const res = {};

    arr.forEach(function (item) {
      if (item === '') return

      const [key, value] = item.split('=');
      res[key] = value ? decodeURIComponent(value) : undefined;
    });

    return res
  }

  const getCookieRegex = /[-.+*]/g;

  function getCookie (key) {
    return !key ? undefined : decodeURIComponent(document.cookie.replace(
      new RegExp(`(?:(?:^|.*;)\\s*${encodeURIComponent(key)
      .replace(getCookieRegex, '\\$&')}\\s*\\=\\s*([^;]*).*$)|^.*$`), '$1')
    ) || undefined
  }

  const loaded = {};

  function loadScript (props) {
    const { el, src, onload, id, innerHTML, link, style } = props;

    // script has already been loaded
    if (loaded[src] && onload) {
      return onload()
    }

    const script = document.createElement(link ? 'link' : style ? 'style' : 'script');
    const e = el || document.head;

    if (link) {
      script.rel = 'stylesheet';
      script.type = ' text/css';
      script.href = src;
      e.appendChild(script);
      return
    }

    script.async = (props.async === undefined) ? true : props.async;

    script.onload = function load () {
      loaded[src] = true;
      if (onload) onload();
    };

    if (id) script.id = id;
    if (src) script.src = src;
    if (innerHTML) script.innerHTML = innerHTML;

    e.appendChild(script);
  }

  function load$1 () {
    loadScript({ src: '//cdn.bizible.com/scripts/bizible.js' });

    window.Bizible = window.Bizible || {
      _queue: [],
      Push: function (o, p) { this._queue.push({ type: o, data: p }); }
    };
  }

  const bizible = { load: load$1 };

  function load$2 (key) {
    loadScript({
      id: 'demandbase_js_lib',
      src: `//scripts.demandbase.com/${key}.min.js`
    });
  }

  function ready (fn) {
    const profile = getProfile();

    if (profile) return fn(false, profile)

    return setTimeout(ready, 500, fn)
  }

  function getProfile () {
    const { Demandbase } = window;

    if (!Demandbase) return

    const { Connectors, IP } = Demandbase;

    if (!Connectors) return

    const { WebForm } = Connectors;

    if (!WebForm) return

    // Email domain (WebForm) takes precedence
    return WebForm.CompanyProfile || IP.CompanyProfile
  }

  function profile () {
    return {
      ip_address: demandbase('ip'),
      db_company_name: demandbase('hq_company_name') || demandbase('company_name'),
      db_demandbase_sid: demandbase('hq_demandbase_sid') || demandbase('demandbase_sid'),
      db_marketing_alias: demandbase('hq_marketing_alias') || demandbase('marketing_alias'),
      db_industry: demandbase('hq_industry') || demandbase('industry'),
      db_sub_industry: demandbase('hq_sub_industry'),
      db_employee_count: demandbase('employee_count'),
      db_primary_sic: demandbase('primary_sic'),
      db_street_address: demandbase('street_address'),
      db_city: demandbase('city'),
      db_state: demandbase('state') || demandbase('registry_state'),
      db_zip: demandbase('zip'),
      db_country: demandbase('country_name') || demandbase('registry_country'),
      db_country_name: demandbase('country_name'),
      db_phone: demandbase('phone'),
      db_stock_ticker: demandbase('stock_ticker'),
      db_web_site: demandbase('web_site'),
      db_annual_sales: demandbase('annual_sales'),
      db_revenue_range: demandbase('revenue_range'),
      db_employee_range: demandbase('employee_range'),
      db_b2b: demandbase('b2b'),
      db_b2c: demandbase('b2c'),
      db_traffic: demandbase('traffic'),
      db_latitude: demandbase('latitude'),
      db_longitude: demandbase('longitude'),
      db_fortune_1000: demandbase('fortune_1000'),
      db_forbes_2000: demandbase('forbes_2000'),
      db_registry_country: demandbase('registry_country'),
      db_registry_state: demandbase('registry_state'),
      db_registry_city: demandbase('registry_city'),
      db_registry_persist_state: demandbase('registry_state'),
      db_registry_persist_country: demandbase('registry_country')
    }
  }

  function demandbase (key) {
    const profile = getProfile();

    if (profile) {
      return profile[key]
    }

    return ''
  }

  demandbase.load = load$2;
  demandbase.ready = ready;
  demandbase.profile = profile;

  function load$3 (key) {
    var analytics = window.analytics = window.analytics || []; if (!analytics.initialize) {
      if (analytics.invoked)window.console && console.error && console.error('Segment snippet included twice.'); else {
        analytics.invoked = !0; analytics.methods = ['trackSubmit', 'trackClick', 'trackLink', 'trackForm', 'pageview', 'identify', 'reset', 'group', 'track', 'ready', 'alias', 'debug', 'page', 'once', 'off', 'on']; analytics.factory = function (t) { return function () { var e = Array.prototype.slice.call(arguments); e.unshift(t); analytics.push(e); return analytics } }; for (var t = 0; t < analytics.methods.length; t++) { var e = analytics.methods[t]; analytics[e] = analytics.factory(e); }analytics.load = function (t, e) { var n = document.createElement('script'); n.type = 'text/javascript'; n.async = !0; n.src = 'https://cdn.segment.com/analytics.js/v1/' + t + '/analytics.min.js'; var a = document.getElementsByTagName('script')[0]; a.parentNode.insertBefore(n, a); analytics._loadOptions = e; }; analytics.SNIPPET_VERSION = '4.1.0';
        analytics.load(key);
      }
    }
  }

  function getContext () {
    const qs = querystring();
    const gaCookie = getCookie('_ga');

    const context = {
      'Google Analytics': {
        clientId: gaCookie ? gaCookie.split('.').slice(-2).join('.') : ''
      }
    };

    const campaign = {};

    if (qs.utm_campaign) campaign.name = qs.utm_campaign;
    if (qs.utm_source) campaign.source = qs.utm_source;
    if (qs.utm_medium) campaign.medium = qs.utm_medium;
    if (qs.utm_term) campaign.term = qs.utm_term;
    if (qs.utm_content) campaign.content = qs.utm_content;
    if (qs.utm_keyword) campaign.keyword = qs.utm_keyword;
    if (qs.utm_network) campaign.network = qs.utm_network;
    if (qs.utm_creative) campaign.creative = qs.utm_creative;
    if (qs.utm_matchtype) campaign.matchtype = qs.utm_matchtype;
    if (qs.gclid) campaign.gclid = qs.gclid;

    if (Object.keys(campaign).length > 0) {
      context.campaign = campaign;
    }

    return context
  }

  function getSignupSource (path = window.location.pathname) {
    if (path.indexOf('/download-center') === 0) {
      return 'www download center'
    }

    if (path === '/cloud/atlas') {
      return 'www atlas overview'
    }

    if (path.indexOf('/cloud/atlas/lp') === 0) {
      return 'www atlas landing page'
    }

    if (path.indexOf('/dr') === 0) {
      return 'www download center postroll'
    }

    if (path === '/cloud/atlas/pricing') {
      return 'www atlas pricing'
    }

    if (path === '/cloud/atlas/signup') {
      return 'www atlas 2 step'
    }

    if (path === '/atlas-signup-from-mlab') {
      return 'mlab'
    }

    return 'www other'
  }

  function page (data = {}, context) {
    if (document.getElementById('atlas-form')) {
      Object.assign(data, { signup_source: getSignupSource() });
    }

    window.analytics.page(document.title, data, getContext());
  }

  function track (name, data) {
    window.analytics.track(name, data, getContext());
  }

  function identify (data) {
    window.analytics.identify(data, getContext());
  }

  function anonymousId () {
    try {
      return window.analytics.user().anonymousId()
    } catch (err) {
      return ''
    }
  }

  const segment = {
    load: load$3,
    page,
    track,
    identify,
    anonymousId,
    getSignupSource
  };

  let key;

  function GUID () {
    return window.GetElqCustomerGUID ? window.GetElqCustomerGUID() : ''
  }

  function post (name, data) {
    return window.fetch('/eloqua', {
      body: JSON.stringify({
        elqSiteID: key,
        elqFormName: name,
        elqCustomerGUID: window.GetElqCustomerGUID ? window.GetElqCustomerGUID() : '',
        elqCookieWrite: 0,
        url: window.location.href,
        gclid: window.sessionStorage.getItem('gclid') || '',
        jump_id: querystring().jmp || window.sessionStorage.getItem('jmp') || getCookie('jmp') || '',
        anonymousId: segment.anonymousId(),
        ...demandbase.profile(),
        ...data
      }),
      credentials: 'include',
      headers: { 'content-type': 'application/json' },
      method: 'POST'
    }).then(function (response) {
      return response.text()
    }).then(function (response) {
      const el = document.createElement('html');
      el.innerHTML = response;

      const script = el.querySelector('script');

      return {
        html: response,
        success: script && script.innerHTML.trim().split('=')[1].includes('Confirmation')
      }
    })
  }

  function load$4 (k) {
    key = k;

    loadScript({
      id: 'eloqua_js_lib_dynamic',
      src: '//img03.en25.com/i/elqCfg.min.js',
      onload () {
        window._elqQ.push(['elqSetSiteId', key]);
        window._elqQ.push(['elqTrackPageView']);
        window._elqQ.push(['elqGetCustomerGUID']);
      }
    });
  }

  const eloqua = { load: load$4, post, GUID };

  function load$5 (key) {
    window.intercomSettings = {
      app_id: key
    };

    if (typeof window.Intercom === 'function') {
      window.Intercom('reattach_activator');
      window.Intercom('update', window.intercomSettings);
      populate();
      return
    }

    const i = function () {
      i.c(arguments);
    };

    i.q = [];
    i.c = function (args) {
      i.q.push(args);
    };

    window.Intercom = i;

    loadScript({ src: '//widget.intercom.io/widget/qq7v0gqb' });
    populate();
  }

  function populate () {
    demandbase.ready(function () {
      window.Intercom('update', {
        db_city: demandbase('city'),
        db_company_name: demandbase('company_name'),
        db_country: demandbase('country_name'),
        db_country_code: demandbase('country'),
        db_employee_count: demandbase('employee_count'),
        db_employee_range: demandbase('employee_range'),
        db_forbes_2000: demandbase('forbes_2000'),
        db_fortune_1000: demandbase('fortune_1000'),
        db_industry: demandbase('industry'),
        db_revenue_range: demandbase('revenue_range'),
        db_web_site: demandbase('web_site')
      });
    });
  }

  const intercom = { load: load$5 };

  function initIntegrationBroker (config = {}) {
    if (typeof window === 'undefined') return {}

    const {
      exclude = [],

      demandbase: demandbaseKey,
      bizible: bizibleTrigger = true,

      adroll: adrollKeys,
      eloqua: eloquaKey,
      intercom: intercomKey,
      segment: segmentKey
    } = config;

    if (isExcluded(exclude)) return {}

    if (bizibleTrigger) bizible.load();

    if (adrollKeys) adroll.load(adrollKeys);
    if (demandbaseKey) demandbase.load(demandbaseKey);
    if (eloquaKey) eloqua.load(eloquaKey);
    if (intercomKey) intercom.load(intercomKey);
    if (segmentKey) segment.load(segmentKey);

    return {
      adroll: window.adroll,
      segment,
      bizible: window.Bizible,
      demandbase,
      eloqua,
      intercom: window.Intercom,
      doTaxes: () => window.open('https://www.google.com/search?q=quickbooks', '_tab')
    }
  }

  function isExcluded (exclude) {
    const { pathname } = window.location;

    if (exclude.filter(function (item) {
      return typeof item === 'string'
        ? pathname.indexOf(item) === 0
        : item.test(pathname)
    }).length > 0) return true
  }

  return initIntegrationBroker;

}));

==> mongodbcom-integration-broker-0.1.9.tgz: package/bundle.js <==
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global = global || self, global.initIntegrationBroker = factory());
}(this, function () { 'use strict';

  function load ({ adv_id, pix_id }) {
    window.adroll_adv_id = adv_id;
    window.adroll_pix_id = pix_id
    ;(function (w, d, e, o, a) { w.__adroll_loaded = true; w.adroll = w.adroll || []; w.adroll.f = ['identify', 'track']; for (a = 0; a < w.adroll.f.length; a++) { w.adroll[w.adroll.f[a]] = w.adroll[w.adroll.f[a]] || (function (n) { return function () { w.adroll.push([n, arguments]); } })(w.adroll.f[a]); }e = d.createElement('script'); o = d.getElementsByTagName('script')[0]; e.async = 1; e.src = 'https://s.adroll.com/j/roundtrip.js'; o.parentNode.insertBefore(e, o); })(window, document);
  }

  const adroll = { load };

  function querystring (str) {
    const arr = (str || window.location.search).slice(1).split('&');
    const res = {};

    arr.forEach(function (item) {
      if (item === '') return

      const [key, value] = item.split('=');
      res[key] = value ? decodeURIComponent(value) : undefined;
    });

    return res
  }

  const getCookieRegex = /[-.+*]/g;

  function getCookie (key) {
    return !key ? undefined : decodeURIComponent(document.cookie.replace(
      new RegExp(`(?:(?:^|.*;)\\s*${encodeURIComponent(key)
      .replace(getCookieRegex, '\\$&')}\\s*\\=\\s*([^;]*).*$)|^.*$`), '$1')
    ) || undefined
  }

  const loaded = {};

  function loadScript (props) {
    const { el, src, onload, id, innerHTML, link, style } = props;

    // script has already been loaded
    if (loaded[src] && onload) {
      return onload()
    }

    const script = document.createElement(link ? 'link' : style ? 'style' : 'script');
    const e = el || document.head;

    if (link) {
      script.rel = 'stylesheet';
      script.type = ' text/css';
      script.href = src;
      e.appendChild(script);
      return
    }

    script.async = (props.async === undefined) ? true : props.async;

    script.onload = function load () {
      loaded[src] = true;
      if (onload) onload();
    };

    if (id) script.id = id;
    if (src) script.src = src;
    if (innerHTML) script.innerHTML = innerHTML;

    e.appendChild(script);
  }

  function load$1 () {
    loadScript({ src: '//cdn.bizible.com/scripts/bizible.js' });

    window.Bizible = window.Bizible || {
      _queue: [],
      Push: function (o, p) { this._queue.push({ type: o, data: p }); }
    };
  }

  const bizible = { load: load$1 };

  function load$2 (key) {
    loadScript({
      id: 'demandbase_js_lib',
      src: `//scripts.demandbase.com/${key}.min.js`
    });
  }

  function ready (fn) {
    const profile = getProfile();

    if (profile) return fn(false, profile)

    return setTimeout(ready, 500, fn)
  }

  function getProfile () {
    const { Demandbase } = window;

    if (!Demandbase) return

    const { Connectors, IP } = Demandbase;

    if (!Connectors) return

    const { WebForm } = Connectors;

    if (!WebForm) return

    // Email domain (WebForm) takes precedence
    return WebForm.CompanyProfile || IP.CompanyProfile
  }

  function profile () {
    return {
      ip_address: demandbase('ip'),
      db_company_name: demandbase('hq_company_name') || demandbase('company_name'),
      db_demandbase_sid: demandbase('hq_demandbase_sid') || demandbase('demandbase_sid'),
      db_marketing_alias: demandbase('hq_marketing_alias') || demandbase('marketing_alias'),
      db_industry: demandbase('hq_industry') || demandbase('industry'),
      db_sub_industry: demandbase('hq_sub_industry'),
      db_employee_count: demandbase('employee_count'),
      db_primary_sic: demandbase('primary_sic'),
      db_street_address: demandbase('street_address'),
      db_city: demandbase('city'),
      db_state: demandbase('state') || demandbase('registry_state'),
      db_zip: demandbase('zip'),
      db_country: demandbase('country_name') || demandbase('registry_country'),
      db_country_name: demandbase('country_name'),
      db_phone: demandbase('phone'),
      db_stock_ticker: demandbase('stock_ticker'),
      db_web_site: demandbase('web_site'),
      db_annual_sales: demandbase('annual_sales'),
      db_revenue_range: demandbase('revenue_range'),
      db_employee_range: demandbase('employee_range'),
      db_b2b: demandbase('b2b'),
      db_b2c: demandbase('b2c'),
      db_traffic: demandbase('traffic'),
      db_latitude: demandbase('latitude'),
      db_longitude: demandbase('longitude'),
      db_fortune_1000: demandbase('fortune_1000'),
      db_forbes_2000: demandbase('forbes_2000'),
      db_registry_country: demandbase('registry_country'),
      db_registry_state: demandbase('registry_state'),
      db_registry_city: demandbase('registry_city'),
      db_registry_persist_state: demandbase('registry_state'),
      db_registry_persist_country: demandbase('registry_country')
    }
  }

  function demandbase (key) {
    const profile = getProfile();

    if (profile) {
      return profile[key]
    }

    return ''
  }

  demandbase.load = load$2;
  demandbase.ready = ready;
  demandbase.profile = profile;

  function minutes (t) {
    return t * 1000 * 60
  }

  function safeParse (str) {
    try { return JSON.parse(str) } catch (err) {}
  }

  function session () {
    const qs = querystring();
    let s = get();

    if (qs.utm_campaign && !s.name) {
      s.name = qs.utm_campaign;
    }
    if (qs.utm_source && !s.source) {
      s.source = qs.utm_source;
    }
    if (qs.utm_medium && !s.medium) {
      s.medium = qs.utm_medium;
    }
    if (qs.utm_term && !s.term) {
      s.term = qs.utm_term;
    }
    if (qs.utm_content && !s.content) {
      s.content = qs.utm_content;
    }
    if (qs.utm_keyword && !s.keyword) {
      s.keyword = qs.utm_keyword;
    }
    if (qs.utm_network && !s.network) {
      s.network = qs.utm_network;
    }
    if (qs.utm_creative && !s.creative) {
      s.creative = qs.utm_creative;
    }
    if (qs.utm_matchtype && !s.matchtype) {
      s.matchtype = qs.utm_matchtype;
    }
    if (qs.gclid && !s.gclid) {
      s.gclid = qs.gclid;
    }
    if (qs.jmp && !s.jmp) {
      s.jmp = qs.jmp;
    }

    window.localStorage.setItem('__session', JSON.stringify(s));
  }

  function get () {
    const s = safeParse(window.localStorage.getItem('__session')) || { timestamp: 0 };

    if ((s.timestamp || 0) < (Date.now() - minutes(30))) {
      return { timestamp: Date.now() }
    } else {
      return s
    }
  }

  session.get = get;

  function load$3 (key) {
    var analytics = window.analytics = window.analytics || []; if (!analytics.initialize) {
      if (analytics.invoked)window.console && console.error && console.error('Segment snippet included twice.'); else {
        analytics.invoked = !0; analytics.methods = ['trackSubmit', 'trackClick', 'trackLink', 'trackForm', 'pageview', 'identify', 'reset', 'group', 'track', 'ready', 'alias', 'debug', 'page', 'once', 'off', 'on']; analytics.factory = function (t) { return function () { var e = Array.prototype.slice.call(arguments); e.unshift(t); analytics.push(e); return analytics } }; for (var t = 0; t < analytics.methods.length; t++) { var e = analytics.methods[t]; analytics[e] = analytics.factory(e); }analytics.load = function (t, e) { var n = document.createElement('script'); n.type = 'text/javascript'; n.async = !0; n.src = 'https://cdn.segment.com/analytics.js/v1/' + t + '/analytics.min.js'; var a = document.getElementsByTagName('script')[0]; a.parentNode.insertBefore(n, a); analytics._loadOptions = e; }; analytics.SNIPPET_VERSION = '4.1.0';
        analytics.load(key);
      }
    }
  }

  function getContext () {
    const s = session.get();
    const gaCookie = getCookie('_ga');

    const context = {
      'Google Analytics': {
        clientId: gaCookie ? gaCookie.split('.').slice(-2).join('.') : ''
      }
    };

    const campaign = {};

    if (s.utm_campaign) campaign.name = s.utm_campaign;
    if (s.utm_source) campaign.source = s.utm_source;
    if (s.utm_medium) campaign.medium = s.utm_medium;
    if (s.utm_term) campaign.term = s.utm_term;
    if (s.utm_content) campaign.content = s.utm_content;
    if (s.utm_keyword) campaign.keyword = s.utm_keyword;
    if (s.utm_network) campaign.network = s.utm_network;
    if (s.utm_creative) campaign.creative = s.utm_creative;
    if (s.utm_matchtype) campaign.matchtype = s.utm_matchtype;
    if (s.gclid) campaign.gclid = s.gclid;

    if (Object.keys(campaign).length > 0) {
      context.campaign = campaign;
    }

    return context
  }

  function getSignupSource (path = window.location.pathname) {
    if (path.indexOf('/download-center') === 0) {
      return 'www download center'
    }

    if (path === '/cloud/atlas') {
      return 'www atlas overview'
    }

    if (path.indexOf('/cloud/atlas/lp') === 0) {
      return 'www atlas landing page'
    }

    if (path.indexOf('/dr') === 0) {
      return 'www download center postroll'
    }

    if (path === '/cloud/atlas/pricing') {
      return 'www atlas pricing'
    }

    if (path === '/cloud/atlas/signup') {
      return 'www atlas 2 step'
    }

    if (path === '/atlas-signup-from-mlab') {
      return 'mlab'
    }

    return 'www other'
  }

  function page (data = {}, context) {
    if (document.getElementById('atlas-form')) {
      Object.assign(data, { signup_source: getSignupSource() });
    }

    window.analytics.page(document.title, data, getContext());
  }

  function track (name, data) {
    window.analytics.track(name, data, getContext());
  }

  function identify (data) {
    window.analytics.identify(data, getContext());
  }

  function anonymousId () {
    try {
      return window.analytics.user().anonymousId()
    } catch (err) {
      return ''
    }
  }

  const segment = {
    load: load$3,
    page,
    track,
    identify,
    anonymousId,
    getSignupSource
  };

  let key;

  function GUID () {
    return window.GetElqCustomerGUID ? window.GetElqCustomerGUID() : ''
  }

  function post (name, data) {
    return window.fetch('/eloqua', {
      body: JSON.stringify({
        elqSiteID: key,
        elqFormName: name,
        elqCustomerGUID: window.GetElqCustomerGUID ? window.GetElqCustomerGUID() : '',
        elqCookieWrite: 0,
        url: window.location.href,
        gclid: window.sessionStorage.getItem('gclid') || '',
        jump_id: querystring().jmp || window.sessionStorage.getItem('jmp') || getCookie('jmp') || '',
        anonymousId: segment.anonymousId(),
        ...demandbase.profile(),
        ...data
      }),
      credentials: 'include',
      headers: { 'content-type': 'application/json' },
      method: 'POST'
    }).then(function (response) {
      return response.text()
    }).then(function (response) {
      const el = document.createElement('html');
      el.innerHTML = response;

      const script = el.querySelector('script');

      return {
        html: response,
        success: script && script.innerHTML.trim().split('=')[1].includes('Confirmation')
      }
    })
  }

  function load$4 (k) {
    key = k;

    loadScript({
      id: 'eloqua_js_lib_dynamic',
      src: '//img03.en25.com/i/elqCfg.min.js',
      onload () {
        window._elqQ.push(['elqSetSiteId', key]);
        window._elqQ.push(['elqTrackPageView']);
        window._elqQ.push(['elqGetCustomerGUID']);
      }
    });
  }

  const eloqua = { load: load$4, post, GUID };

  function load$5 (key) {
    window.intercomSettings = {
      app_id: key
    };

    if (typeof window.Intercom === 'function') {
      window.Intercom('reattach_activator');
      window.Intercom('update', window.intercomSettings);
      populate();
      return
    }

    const i = function () {
      i.c(arguments);
    };

    i.q = [];
    i.c = function (args) {
      i.q.push(args);
    };

    window.Intercom = i;

    loadScript({ src: '//widget.intercom.io/widget/qq7v0gqb' });
    populate();
  }

  function populate () {
    demandbase.ready(function () {
      window.Intercom('update', {
        db_city: demandbase('city'),
        db_company_name: demandbase('company_name'),
        db_country: demandbase('country_name'),
        db_country_code: demandbase('country'),
        db_employee_count: demandbase('employee_count'),
        db_employee_range: demandbase('employee_range'),
        db_forbes_2000: demandbase('forbes_2000'),
        db_fortune_1000: demandbase('fortune_1000'),
        db_industry: demandbase('industry'),
        db_revenue_range: demandbase('revenue_range'),
        db_web_site: demandbase('web_site')
      });
    });
  }

  const intercom = { load: load$5 };

  function tagManager () {
    (function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src='//www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);})(window,document,'script','dataLayer','GTM-GDFN');
  }

  function initIntegrationBroker (config = {}) {
    if (typeof window === 'undefined') return {}

    const {
      exclude = [],

      demandbase: demandbaseKey,
      bizible: bizibleTrigger,
      tagManager: tagManagerTrigger,

      adroll: adrollKeys,
      eloqua: eloquaKey,
      intercom: intercomKey,
      segment: segmentKey
    } = config;

    if (isExcluded(exclude)) return {}

    if (bizibleTrigger !== false) bizible.load();
    if (tagManagerTrigger !== false) tagManager();

    if (adrollKeys) adroll.load(adrollKeys);
    if (demandbaseKey) demandbase.load(demandbaseKey);
    if (eloquaKey) eloqua.load(eloquaKey);
    if (intercomKey) intercom.load(intercomKey);
    if (segmentKey) segment.load(segmentKey);

    session();

    return {
      adroll: window.adroll,
      session,
      segment,
      bizible: window.Bizible,
      demandbase,
      eloqua,
      intercom: window.Intercom,
      doTaxes: () => window.open('https://www.google.com/search?q=quickbooks', '_tab')
    }
  }

  function isExcluded (exclude) {
    const { pathname } = window.location;

    if (exclude.filter(function (item) {
      return typeof item === 'string'
        ? pathname.indexOf(item) === 0
        : item.test(pathname)
    }).length > 0) return true
  }

  return initIntegrationBroker;

}));
